# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_statement_object import ServerStatementObject  # noqa: F401,E501
from kba.models.server_statement_predicate import ServerStatementPredicate  # noqa: F401,E501
from kba.models.server_statement_subject import ServerStatementSubject  # noqa: F401,E501


class ServerStatement(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'subject': 'ServerStatementSubject',
        'predicate': 'ServerStatementPredicate',
        'object': 'ServerStatementObject',
        'beacon': 'int'
    }

    attribute_map = {
        'id': 'id',
        'subject': 'subject',
        'predicate': 'predicate',
        'object': 'object',
        'beacon': 'beacon'
    }

    def __init__(self, id=None, subject=None, predicate=None, object=None, beacon=None):  # noqa: E501
        """ServerStatement - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._subject = None
        self._predicate = None
        self._object = None
        self._beacon = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if subject is not None:
            self.subject = subject
        if predicate is not None:
            self.predicate = predicate
        if object is not None:
            self.object = object
        if beacon is not None:
            self.beacon = beacon

    @property
    def id(self):
        """Gets the id of this ServerStatement.  # noqa: E501

        CURIE-encoded identifier for statement (can be used to retrieve associated evidence)  # noqa: E501

        :return: The id of this ServerStatement.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerStatement.

        CURIE-encoded identifier for statement (can be used to retrieve associated evidence)  # noqa: E501

        :param id: The id of this ServerStatement.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def subject(self):
        """Gets the subject of this ServerStatement.  # noqa: E501


        :return: The subject of this ServerStatement.  # noqa: E501
        :rtype: ServerStatementSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this ServerStatement.


        :param subject: The subject of this ServerStatement.  # noqa: E501
        :type: ServerStatementSubject
        """

        self._subject = subject

    @property
    def predicate(self):
        """Gets the predicate of this ServerStatement.  # noqa: E501


        :return: The predicate of this ServerStatement.  # noqa: E501
        :rtype: ServerStatementPredicate
        """
        return self._predicate

    @predicate.setter
    def predicate(self, predicate):
        """Sets the predicate of this ServerStatement.


        :param predicate: The predicate of this ServerStatement.  # noqa: E501
        :type: ServerStatementPredicate
        """

        self._predicate = predicate

    @property
    def object(self):
        """Gets the object of this ServerStatement.  # noqa: E501


        :return: The object of this ServerStatement.  # noqa: E501
        :rtype: ServerStatementObject
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this ServerStatement.


        :param object: The object of this ServerStatement.  # noqa: E501
        :type: ServerStatementObject
        """

        self._object = object

    @property
    def beacon(self):
        """Gets the beacon of this ServerStatement.  # noqa: E501

        aggregator assigned beacon index number   # noqa: E501

        :return: The beacon of this ServerStatement.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerStatement.

        aggregator assigned beacon index number   # noqa: E501

        :param beacon: The beacon of this ServerStatement.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_knowledge_map_object import ServerKnowledgeMapObject  # noqa: F401,E501
from kba.models.server_knowledge_map_predicate import ServerKnowledgeMapPredicate  # noqa: F401,E501
from kba.models.server_knowledge_map_subject import ServerKnowledgeMapSubject  # noqa: F401,E501


class ServerKnowledgeMapStatement(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject': 'ServerKnowledgeMapSubject',
        'predicate': 'ServerKnowledgeMapPredicate',
        'object': 'ServerKnowledgeMapObject',
        'frequency': 'int',
        'description': 'str'
    }

    attribute_map = {
        'subject': 'subject',
        'predicate': 'predicate',
        'object': 'object',
        'frequency': 'frequency',
        'description': 'description'
    }

    def __init__(self, subject=None, predicate=None, object=None, frequency=None, description=None):  # noqa: E501
        """ServerKnowledgeMapStatement - a model defined in Swagger"""  # noqa: E501

        self._subject = None
        self._predicate = None
        self._object = None
        self._frequency = None
        self._description = None
        self.discriminator = None

        if subject is not None:
            self.subject = subject
        if predicate is not None:
            self.predicate = predicate
        if object is not None:
            self.object = object
        if frequency is not None:
            self.frequency = frequency
        if description is not None:
            self.description = description

    @property
    def subject(self):
        """Gets the subject of this ServerKnowledgeMapStatement.  # noqa: E501


        :return: The subject of this ServerKnowledgeMapStatement.  # noqa: E501
        :rtype: ServerKnowledgeMapSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this ServerKnowledgeMapStatement.


        :param subject: The subject of this ServerKnowledgeMapStatement.  # noqa: E501
        :type: ServerKnowledgeMapSubject
        """

        self._subject = subject

    @property
    def predicate(self):
        """Gets the predicate of this ServerKnowledgeMapStatement.  # noqa: E501


        :return: The predicate of this ServerKnowledgeMapStatement.  # noqa: E501
        :rtype: ServerKnowledgeMapPredicate
        """
        return self._predicate

    @predicate.setter
    def predicate(self, predicate):
        """Sets the predicate of this ServerKnowledgeMapStatement.


        :param predicate: The predicate of this ServerKnowledgeMapStatement.  # noqa: E501
        :type: ServerKnowledgeMapPredicate
        """

        self._predicate = predicate

    @property
    def object(self):
        """Gets the object of this ServerKnowledgeMapStatement.  # noqa: E501


        :return: The object of this ServerKnowledgeMapStatement.  # noqa: E501
        :rtype: ServerKnowledgeMapObject
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this ServerKnowledgeMapStatement.


        :param object: The object of this ServerKnowledgeMapStatement.  # noqa: E501
        :type: ServerKnowledgeMapObject
        """

        self._object = object

    @property
    def frequency(self):
        """Gets the frequency of this ServerKnowledgeMapStatement.  # noqa: E501

        the frequency of statements of the specified relationship within the given beacon   # noqa: E501

        :return: The frequency of this ServerKnowledgeMapStatement.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ServerKnowledgeMapStatement.

        the frequency of statements of the specified relationship within the given beacon   # noqa: E501

        :param frequency: The frequency of this ServerKnowledgeMapStatement.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    @property
    def description(self):
        """Gets the description of this ServerKnowledgeMapStatement.  # noqa: E501

        a description of the nature of the relationship   # noqa: E501

        :return: The description of this ServerKnowledgeMapStatement.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServerKnowledgeMapStatement.

        a description of the nature of the relationship   # noqa: E501

        :param description: The description of this ServerKnowledgeMapStatement.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerKnowledgeMapStatement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerClique(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'clique_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'clique_id': 'cliqueId'
    }

    def __init__(self, id=None, clique_id=None):  # noqa: E501
        """ServerClique - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._clique_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if clique_id is not None:
            self.clique_id = clique_id

    @property
    def id(self):
        """Gets the id of this ServerClique.  # noqa: E501

        CURIE identifying the concept whose concept clique is being resolved   # noqa: E501

        :return: The id of this ServerClique.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerClique.

        CURIE identifying the concept whose concept clique is being resolved   # noqa: E501

        :param id: The id of this ServerClique.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def clique_id(self):
        """Gets the clique_id of this ServerClique.  # noqa: E501

        CURIE identifying the equivalent concept clique to which the  input concept CURIE belongs.   # noqa: E501

        :return: The clique_id of this ServerClique.  # noqa: E501
        :rtype: str
        """
        return self._clique_id

    @clique_id.setter
    def clique_id(self, clique_id):
        """Sets the clique_id of this ServerClique.

        CURIE identifying the equivalent concept clique to which the  input concept CURIE belongs.   # noqa: E501

        :param clique_id: The clique_id of this ServerClique.  # noqa: E501
        :type: str
        """

        self._clique_id = clique_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerClique):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import click, time, os, pprint, pickle

from progress.spinner import Spinner as _Spinner

class Spinner(_Spinner):
    phases = ['x', '|', '-', '+']
    def clearln(self):
        print('\r\x1b[K', end='', file=self.file)

from kba.utils import AggregatorApi
from kba import ConceptsApi, StatementsApi, MetadataApi

aggregator = AggregatorApi()

STATE = 'cli_state.pickle'

def save(state:dict) -> None:
    with open(STATE, 'wb') as f:
        pickle.dump(state, f, protocol=pickle.HIGHEST_PROTOCOL)

def load() -> dict:
    with open(STATE, 'rb') as handle:
        return pickle.load(handle)

def join(thread, message='Waiting for response ', seconds=0.1):
    """
    Waits for thread to finish, and then returns result
    """
    spinner = Spinner(message)

    while not thread.ready():
        time.sleep(seconds)
        spinner.next()

    spinner.clearln()

    return thread.get()

@click.group()
def cli():
    pass

@cli.command()
@click.option('--keywords', '-k', multiple=True, required=True, help='A list of keywords to use for a substring match')
@click.option('--categories', '-c', multiple=True)
@click.option('--beacons', '-b', multiple=True, type=list)
def concept(keywords, categories, beacons):
    """
    Initiates a concept query with the given search parameters
    """
    kwargs = {}
    if categories is not None:
        kwargs['categories'] = list(categories)
    if beacons is not None:
        kwargs['beacons'] = list(beacons)

    thread = ConceptsApi().post_concepts_query(keywords=keywords, **kwargs, async=True)

    response = join(thread, 'Waiting for response ')

    click.echo('Query ID:\t{}'.format(response.query_id))

    save({'query' : response.query_id, 'command' : 'concept'})

@cli.command()
@click.option('--source', '-s', type=str, multiple=True)
@click.option('--relation', '-r', type=str, multiple=True)
@click.option('--target', '-t', type=str, multiple=True)
@click.option('--keyword', '-k', type=str, multiple=True)
@click.option('--category', '-c', type=str, multiple=True)
@click.option('--beacon', '-b', type=int, multiple=True)
def statement(source, relation, target, keyword, category, beacon):
    """
    Initiates a statement query with the given search parameters
    """
    kwargs = {}
    if source is not None:
        kwargs['source'] = list(source)
    if relation is not None:
        kwargs['relations'] = list(relation)
    if target is not None:
        kwargs['target'] = list(target)
    if keyword is not None:
        kwargs['keywords'] = list(keyword)
    if category is not None:
        kwargs['categories'] = list(category)
    if beacon is not None:
        kwargs['beacons'] = list(beacon)

    thread = StatementsApi().post_statements_query(**kwargs, async=True)

    response = join(thread, 'Waiting for response ')

    click.echo('Query ID:\t{}'.format(response.query_id))

    save({'query' : response.query_id, 'command' : 'statement'})

@cli.command()
@click.option('--query', '-q', help='A query ID')
@click.option('--command', '-c', type=click.Choice(['concept', 'statement']), help='The command that produced the given query ID, to help us know which endpoint to use')
def ping(query, command):
    """
    Retrieves the status of a query (by default the last query)
    """
    state = load()

    if query is None:
        query = state['query']
        click.echo('Last query:\t{}'.format(query))
    else:
        click.echo('Query ID:\t{}'.format(query))

    if command is None:
        command = state['command']

    if command == 'concept':
        thread = ConceptsApi().get_concepts_query_status(query, async=True)
    elif command == 'statement':
        thread = StatementsApi().get_statements_query_status(query, async=True)
    else:
        raise Exception('Unknown command {}'.format(command))

    response = join(thread, 'Waiting for response ')

    statuses = response.status
    statuses.sort(key=lambda s: s.beacon)

    for status in statuses:
        if status.count is not None:
            click.echo('Beacon {} finished with {} records'.format(status.beacon, status.count))
        elif status.discovered is not None:
            click.echo('Beacon {} discovered {} records, processed {}'.format(status.beacon, status.discovered, status.processed))
        else:
            click.echo('Beacon {} has not yet returned'.format(status.beacon))

@cli.command()
@click.option('--query', '-q', help='A query ID')
@click.option('--command', '-c', type=click.Choice(['concept', 'statement']), help='The command that produced the given query ID, to help us know which endpoint to use')
@click.option('--out', '-o', type=click.Path(), help='If provided, the results of the query will be written to this file instead of sent to standard out')
@click.option('--page', type=int, default=1, help='The ordinal number of the page to get (1=first, 2=second, etc.)')
@click.option('--size', type=int, default=100, help='The size of page to get')
def dump(query, command, out, page, size):
    """
    Retrieves the results of a query (by default the last query)
    """
    state = load()

    if query is None:
        query = state['query']
        click.echo('Last query:\t{}'.format(query))
    else:
        click.echo('Query ID:\t{}'.format(query))

    if command is None:
        command = state['command']

    if command == 'concept':
        thread = ConceptsApi().get_concepts(query, page_number=page, page_size=size, async=True)
    elif command == 'statement':
        thread = StatementsApi().get_statements(query, page_number=page, page_size=size, async=True)
    else:
        raise Exception('Unknown command {}'.format(command))

    response = join(thread, 'Waiting for response ')

    if out is not None:
        with open(out, 'w+') as f:
            f.write(str(response))
            click.echo('Saved response to {}'.format(out))
    else:
        pprint.pprint(response)

@cli.command()
@click.option('--out', '-o', type=click.Path(), help='If provided, query results will be saved to the given file')
def predicates(out):
    """
    Retrieves all predicates
    """
    thread = MetadataApi().get_predicates(async=True)
    response = join(thread)

    if out is not None:
        with open(out, 'w+') as f:
            f.write(str(response))
            click.echo('Saved response to {}'.format(out))
    else:
        pprint.pprint(response)

@cli.command()
@click.option('--out', '-o', type=click.Path(), help='If provided, query results will be saved to the given file')
def kmap(out):
    """
    Retrieves the knowledge map
    """
    thread = MetadataApi().get_knowledge_map(async=True)
    response = join(thread)

    if out is not None:
        with open(out, 'w+') as f:
            f.write(str(response))
            click.echo('Saved response to {}'.format(out))
    else:
        pprint.pprint(response)

@cli.command()
@click.option('--out', '-o', type=click.Path(), help='If provided, query results will be saved to the given file')
def categories(out):
    """
    Retrieves all categories
    """
    thread = MetadataApi().get_concept_categories(async=True)
    response = join(thread)

    if out is not None:
        with open(out, 'w+') as f:
            f.write(str(response))
            click.echo('Saved response to {}'.format(out))
    else:
        pprint.pprint(response)

@cli.command()
@click.option('--out', '-o', type=click.Path(), help='If provided, query results will be saved to the given file')
def beacons(out):
    """
    Retrieves all beacons
    """
    thread = MetadataApi().get_beacons(async=True)
    response = join(thread)

    if out is not None:
        with open(out, 'w+') as f:
            f.write(str(response))
            click.echo('Saved response to {}'.format(out))
    else:
        pprint.pprint(response)



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerBeaconPredicate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'uri': 'str',
        'relation': 'str',
        'description': 'str',
        'frequency': 'int'
    }

    attribute_map = {
        'id': 'id',
        'uri': 'uri',
        'relation': 'relation',
        'description': 'description',
        'frequency': 'frequency'
    }

    def __init__(self, id=None, uri=None, relation=None, description=None, frequency=None):  # noqa: E501
        """ServerBeaconPredicate - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._uri = None
        self._relation = None
        self._description = None
        self._frequency = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri
        if relation is not None:
            self.relation = relation
        if description is not None:
            self.description = description
        if frequency is not None:
            self.frequency = frequency

    @property
    def id(self):
        """Gets the id of this ServerBeaconPredicate.  # noqa: E501

        the 'local' CURIE-encoded identifier of a maximal predicate relation, as published by  the given beacon   # noqa: E501

        :return: The id of this ServerBeaconPredicate.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerBeaconPredicate.

        the 'local' CURIE-encoded identifier of a maximal predicate relation, as published by  the given beacon   # noqa: E501

        :param id: The id of this ServerBeaconPredicate.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this ServerBeaconPredicate.  # noqa: E501

        the 'local' URI of a maximal predicate relation,  as published by the given beacon   # noqa: E501

        :return: The uri of this ServerBeaconPredicate.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ServerBeaconPredicate.

        the 'local' URI of a maximal predicate relation,  as published by the given beacon   # noqa: E501

        :param uri: The uri of this ServerBeaconPredicate.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def relation(self):
        """Gets the relation of this ServerBeaconPredicate.  # noqa: E501

        the human readable 'relation of the 'maximal' predicate (see the [Biolink Model](https://biolink.github.io/biolink-model) for a list of Biolink maximal predicates; this field may map onto beacon-specific non-Biolink relations   # noqa: E501

        :return: The relation of this ServerBeaconPredicate.  # noqa: E501
        :rtype: str
        """
        return self._relation

    @relation.setter
    def relation(self, relation):
        """Sets the relation of this ServerBeaconPredicate.

        the human readable 'relation of the 'maximal' predicate (see the [Biolink Model](https://biolink.github.io/biolink-model) for a list of Biolink maximal predicates; this field may map onto beacon-specific non-Biolink relations   # noqa: E501

        :param relation: The relation of this ServerBeaconPredicate.  # noqa: E501
        :type: str
        """

        self._relation = relation

    @property
    def description(self):
        """Gets the description of this ServerBeaconPredicate.  # noqa: E501

        human readable definition of the given predicate relation   # noqa: E501

        :return: The description of this ServerBeaconPredicate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServerBeaconPredicate.

        human readable definition of the given predicate relation   # noqa: E501

        :param description: The description of this ServerBeaconPredicate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def frequency(self):
        """Gets the frequency of this ServerBeaconPredicate.  # noqa: E501

        the number of instances of the specified predicate relation is used in statements within the given beacon   # noqa: E501

        :return: The frequency of this ServerBeaconPredicate.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ServerBeaconPredicate.

        the number of instances of the specified predicate relation is used in statements within the given beacon   # noqa: E501

        :param frequency: The frequency of this ServerBeaconPredicate.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerBeaconPredicate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kba.api_client import ApiClient


class StatementsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_statement_details(self, statement_id, **kwargs):  # noqa: E501
        """get_statement_details  # noqa: E501

        Retrieves a details relating to a specified concept-relationship statement include 'is_defined_by and 'provided_by' provenance; extended edge properties exported as tag = value; and any associated annotations (publications, etc.)  cited as evidence for the given statement.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statement_details(statement_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str statement_id: (url-encoded) CURIE identifier of the concept-relationship statement (\"assertion\", \"claim\") for which associated evidence is sought, e.g. kbs:Q420626_P2175_Q126691  (required)
        :param list[str] keywords: an array of keywords or substrings against which to filter a reference label (e.g. title) statement evidence citation array.
        :param int page_number: (1-based) number of the page to be returned in a paged set of statement.evidence array entries. Defaults to 1.
        :param int page_size: number of cited references per page to be returned in a paged set of statement.evidence array entries. Defaults to '10'.
        :return: ServerStatementDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_statement_details_with_http_info(statement_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_statement_details_with_http_info(statement_id, **kwargs)  # noqa: E501
            return data

    def get_statement_details_with_http_info(self, statement_id, **kwargs):  # noqa: E501
        """get_statement_details  # noqa: E501

        Retrieves a details relating to a specified concept-relationship statement include 'is_defined_by and 'provided_by' provenance; extended edge properties exported as tag = value; and any associated annotations (publications, etc.)  cited as evidence for the given statement.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statement_details_with_http_info(statement_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str statement_id: (url-encoded) CURIE identifier of the concept-relationship statement (\"assertion\", \"claim\") for which associated evidence is sought, e.g. kbs:Q420626_P2175_Q126691  (required)
        :param list[str] keywords: an array of keywords or substrings against which to filter a reference label (e.g. title) statement evidence citation array.
        :param int page_number: (1-based) number of the page to be returned in a paged set of statement.evidence array entries. Defaults to 1.
        :param int page_size: number of cited references per page to be returned in a paged set of statement.evidence array entries. Defaults to '10'.
        :return: ServerStatementDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['statement_id', 'keywords', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_statement_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'statement_id' is set
        if ('statement_id' not in params or
                params['statement_id'] is None):
            raise ValueError("Missing the required parameter `statement_id` when calling `get_statement_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'statement_id' in params:
            path_params['statementId'] = params['statement_id']  # noqa: E501

        query_params = []
        if 'keywords' in params:
            query_params.append(('keywords', params['keywords']))  # noqa: E501
            collection_formats['keywords'] = 'csv'  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/statements/details/{statementId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerStatementDetails',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_statements(self, query_id, **kwargs):  # noqa: E501
        """get_statements  # noqa: E501

        Given a specification [CURIE-encoded](https://www.w3.org/TR/curie/) a 'source' clique identifier for a set of exactly matching concepts, retrieves a paged list of concept-relations where either the subject or object concept matches the 'source' clique identifier.  Optionally, a 'target' clique identifier may also be given, in which case the 'target' clique identifier should match the concept clique opposing the 'source', that is, if the 'source' matches a subject, then the  'target' should match the object of a given statement (or vice versa).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statements(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of statement query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose statements are to be retrieved
        :param int page_number: (1-based) number of the page to be returned in a paged set of query results. Defaults to '1'.
        :param int page_size: number of concepts per page to be returned in a paged set of query results. Defaults to '10'.
        :return: ServerStatementsQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_statements_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_statements_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_statements_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_statements  # noqa: E501

        Given a specification [CURIE-encoded](https://www.w3.org/TR/curie/) a 'source' clique identifier for a set of exactly matching concepts, retrieves a paged list of concept-relations where either the subject or object concept matches the 'source' clique identifier.  Optionally, a 'target' clique identifier may also be given, in which case the 'target' clique identifier should match the concept clique opposing the 'source', that is, if the 'source' matches a subject, then the  'target' should match the object of a given statement (or vice versa).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statements_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of statement query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose statements are to be retrieved
        :param int page_number: (1-based) number of the page to be returned in a paged set of query results. Defaults to '1'.
        :param int page_size: number of concepts per page to be returned in a paged set of query results. Defaults to '10'.
        :return: ServerStatementsQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id', 'beacons', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_statements" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_statements`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/statements/data/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerStatementsQueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_statements_query_status(self, query_id, **kwargs):  # noqa: E501
        """get_statements_query_status  # noqa: E501

        Retrieves the status of a given query about the statements in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statements_query_status(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of statements query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose status is being polled (if omitted, then the status of all beacons from the query are returned)
        :return: ServerStatementsQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_statements_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_statements_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_statements_query_status_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_statements_query_status  # noqa: E501

        Retrieves the status of a given query about the statements in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_statements_query_status_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of statements query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose status is being polled (if omitted, then the status of all beacons from the query are returned)
        :return: ServerStatementsQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id', 'beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_statements_query_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_statements_query_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/statements/status/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerStatementsQueryStatus',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_statements_query(self, source, **kwargs):  # noqa: E501
        """post_statements_query  # noqa: E501

        Posts a query to retrieve concept-relations where either the subject or object concept matches a [CURIE-encoded 'source'](https://www.w3.org/TR/curie/) clique identifier designating a set of exactly matching concepts. A 'target' clique identifier may optionally be given, in which case the 'target' clique identifier should match the concept clique opposing the 'source', that is, if the 'source' matches a subject, then the  'target' should match the object of a given statement (or vice versa).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_statements_query(source, async=True)
        >>> result = thread.get()

        :param async bool
        :param str source: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier of the exactly matching 'source' clique, cliques as identified by other endpoints of the beacon aggregator API.  (required)
        :param list[str] relations: a subset (array) of identifiers of predicate relation identifiers with which to constrain the statement relations retrieved  for the given query seed concept. The predicate ids sent should  be as published by the beacon-aggregator by the /predicates API endpoint.
        :param str target: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier of the exactly matching 'target' clique, cliques as identified by other endpoints of the beacon aggregator API.
        :param list[str] keywords: an array of keywords or substrings against which to match the 'target' concept or 'predicate' names of the set of concept-relations matched by the 'source' concepts.
        :param list[str] categories: a subset (array) of identifiers of concept categories to which to constrain 'target' concepts associated with the given 'source' concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).
        :param list[int] beacons: set of aggregator indices of beacons to be used as knowledge sources for the query
        :return: ServerStatementsQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.post_statements_query_with_http_info(source, **kwargs)  # noqa: E501
        else:
            (data) = self.post_statements_query_with_http_info(source, **kwargs)  # noqa: E501
            return data

    def post_statements_query_with_http_info(self, source, **kwargs):  # noqa: E501
        """post_statements_query  # noqa: E501

        Posts a query to retrieve concept-relations where either the subject or object concept matches a [CURIE-encoded 'source'](https://www.w3.org/TR/curie/) clique identifier designating a set of exactly matching concepts. A 'target' clique identifier may optionally be given, in which case the 'target' clique identifier should match the concept clique opposing the 'source', that is, if the 'source' matches a subject, then the  'target' should match the object of a given statement (or vice versa).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_statements_query_with_http_info(source, async=True)
        >>> result = thread.get()

        :param async bool
        :param str source: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier of the exactly matching 'source' clique, cliques as identified by other endpoints of the beacon aggregator API.  (required)
        :param list[str] relations: a subset (array) of identifiers of predicate relation identifiers with which to constrain the statement relations retrieved  for the given query seed concept. The predicate ids sent should  be as published by the beacon-aggregator by the /predicates API endpoint.
        :param str target: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier of the exactly matching 'target' clique, cliques as identified by other endpoints of the beacon aggregator API.
        :param list[str] keywords: an array of keywords or substrings against which to match the 'target' concept or 'predicate' names of the set of concept-relations matched by the 'source' concepts.
        :param list[str] categories: a subset (array) of identifiers of concept categories to which to constrain 'target' concepts associated with the given 'source' concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).
        :param list[int] beacons: set of aggregator indices of beacons to be used as knowledge sources for the query
        :return: ServerStatementsQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['source', 'relations', 'target', 'keywords', 'categories', 'beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_statements_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'source' is set
        if ('source' not in params or
                params['source'] is None):
            raise ValueError("Missing the required parameter `source` when calling `post_statements_query`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'source' in params:
            query_params.append(('source', params['source']))  # noqa: E501
        if 'relations' in params:
            query_params.append(('relations', params['relations']))  # noqa: E501
            collection_formats['relations'] = 'csv'  # noqa: E501
        if 'target' in params:
            query_params.append(('target', params['target']))  # noqa: E501
        if 'keywords' in params:
            query_params.append(('keywords', params['keywords']))  # noqa: E501
            collection_formats['keywords'] = 'csv'  # noqa: E501
        if 'categories' in params:
            query_params.append(('categories', params['categories']))  # noqa: E501
            collection_formats['categories'] = 'csv'  # noqa: E501
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/statements', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerStatementsQuery',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_cliques_query_beacon_status import ServerCliquesQueryBeaconStatus  # noqa: F401,E501


class ServerCliquesQueryStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'status': 'list[ServerCliquesQueryBeaconStatus]'
    }

    attribute_map = {
        'query_id': 'queryId',
        'status': 'status'
    }

    def __init__(self, query_id=None, status=None):  # noqa: E501
        """ServerCliquesQueryStatus - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._status = None
        self.discriminator = None

        if query_id is not None:
            self.query_id = query_id
        if status is not None:
            self.status = status

    @property
    def query_id(self):
        """Gets the query_id of this ServerCliquesQueryStatus.  # noqa: E501

        session identifier of a query previously initiated by /cliques   # noqa: E501

        :return: The query_id of this ServerCliquesQueryStatus.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this ServerCliquesQueryStatus.

        session identifier of a query previously initiated by /cliques   # noqa: E501

        :param query_id: The query_id of this ServerCliquesQueryStatus.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def status(self):
        """Gets the status of this ServerCliquesQueryStatus.  # noqa: E501

        array of beacon-specific query status reports   # noqa: E501

        :return: The status of this ServerCliquesQueryStatus.  # noqa: E501
        :rtype: list[ServerCliquesQueryBeaconStatus]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ServerCliquesQueryStatus.

        array of beacon-specific query status reports   # noqa: E501

        :param status: The status of this ServerCliquesQueryStatus.  # noqa: E501
        :type: list[ServerCliquesQueryBeaconStatus]
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerCliquesQueryStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerLogEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'timestamp': 'str',
        'beacon': 'int',
        'query': 'str',
        'message': 'str'
    }

    attribute_map = {
        'query_id': 'queryId',
        'timestamp': 'timestamp',
        'beacon': 'beacon',
        'query': 'query',
        'message': 'message'
    }

    def __init__(self, query_id=None, timestamp=None, beacon=None, query=None, message=None):  # noqa: E501
        """ServerLogEntry - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._timestamp = None
        self._beacon = None
        self._query = None
        self._message = None
        self.discriminator = None

        if query_id is not None:
            self.query_id = query_id
        if timestamp is not None:
            self.timestamp = timestamp
        if beacon is not None:
            self.beacon = beacon
        if query is not None:
            self.query = query
        if message is not None:
            self.message = message

    @property
    def query_id(self):
        """Gets the query_id of this ServerLogEntry.  # noqa: E501

        session identifier of initiated query   # noqa: E501

        :return: The query_id of this ServerLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this ServerLogEntry.

        session identifier of initiated query   # noqa: E501

        :param query_id: The query_id of this ServerLogEntry.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def timestamp(self):
        """Gets the timestamp of this ServerLogEntry.  # noqa: E501

        timestamp   # noqa: E501

        :return: The timestamp of this ServerLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ServerLogEntry.

        timestamp   # noqa: E501

        :param timestamp: The timestamp of this ServerLogEntry.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def beacon(self):
        """Gets the beacon of this ServerLogEntry.  # noqa: E501

        aggregator assigned beacon index identifier   # noqa: E501

        :return: The beacon of this ServerLogEntry.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerLogEntry.

        aggregator assigned beacon index identifier   # noqa: E501

        :param beacon: The beacon of this ServerLogEntry.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def query(self):
        """Gets the query of this ServerLogEntry.  # noqa: E501

        URL of the API call executed by the aggregator   # noqa: E501

        :return: The query of this ServerLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this ServerLogEntry.

        URL of the API call executed by the aggregator   # noqa: E501

        :param query: The query of this ServerLogEntry.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def message(self):
        """Gets the message of this ServerLogEntry.  # noqa: E501

        error message   # noqa: E501

        :return: The message of this ServerLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ServerLogEntry.

        error message   # noqa: E501

        :param message: The message of this ServerLogEntry.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerLogEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_concept_detail import ServerConceptDetail  # noqa: F401,E501


class ServerConceptWithDetailsBeaconEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'id': 'str',
        'synonyms': 'list[str]',
        'definition': 'str',
        'details': 'list[ServerConceptDetail]'
    }

    attribute_map = {
        'beacon': 'beacon',
        'id': 'id',
        'synonyms': 'synonyms',
        'definition': 'definition',
        'details': 'details'
    }

    def __init__(self, beacon=None, id=None, synonyms=None, definition=None, details=None):  # noqa: E501
        """ServerConceptWithDetailsBeaconEntry - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._id = None
        self._synonyms = None
        self._definition = None
        self._details = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if id is not None:
            self.id = id
        if synonyms is not None:
            self.synonyms = synonyms
        if definition is not None:
            self.definition = definition
        if details is not None:
            self.details = details

    @property
    def beacon(self):
        """Gets the beacon of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501

        Index number of beacon providing these concept details   # noqa: E501

        :return: The beacon of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerConceptWithDetailsBeaconEntry.

        Index number of beacon providing these concept details   # noqa: E501

        :param beacon: The beacon of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def id(self):
        """Gets the id of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501

        CURIE identifying the specific beacon source concept being described.   # noqa: E501

        :return: The id of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerConceptWithDetailsBeaconEntry.

        CURIE identifying the specific beacon source concept being described.   # noqa: E501

        :param id: The id of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def synonyms(self):
        """Gets the synonyms of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501

        List of synonymous names or identifiers for the concept   # noqa: E501

        :return: The synonyms of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._synonyms

    @synonyms.setter
    def synonyms(self, synonyms):
        """Sets the synonyms of this ServerConceptWithDetailsBeaconEntry.

        List of synonymous names or identifiers for the concept   # noqa: E501

        :param synonyms: The synonyms of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :type: list[str]
        """

        self._synonyms = synonyms

    @property
    def definition(self):
        """Gets the definition of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501

        Concept definition provided by a given beacon   # noqa: E501

        :return: The definition of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :rtype: str
        """
        return self._definition

    @definition.setter
    def definition(self, definition):
        """Sets the definition of this ServerConceptWithDetailsBeaconEntry.

        Concept definition provided by a given beacon   # noqa: E501

        :param definition: The definition of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :type: str
        """

        self._definition = definition

    @property
    def details(self):
        """Gets the details of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501


        :return: The details of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :rtype: list[ServerConceptDetail]
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this ServerConceptWithDetailsBeaconEntry.


        :param details: The details of this ServerConceptWithDetailsBeaconEntry.  # noqa: E501
        :type: list[ServerConceptDetail]
        """

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConceptWithDetailsBeaconEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerStatementSubject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'clique': 'str',
        'id': 'str',
        'name': 'str',
        'categories': 'list[str]'
    }

    attribute_map = {
        'clique': 'clique',
        'id': 'id',
        'name': 'name',
        'categories': 'categories'
    }

    def __init__(self, clique=None, id=None, name=None, categories=None):  # noqa: E501
        """ServerStatementSubject - a model defined in Swagger"""  # noqa: E501

        self._clique = None
        self._id = None
        self._name = None
        self._categories = None
        self.discriminator = None

        if clique is not None:
            self.clique = clique
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if categories is not None:
            self.categories = categories

    @property
    def clique(self):
        """Gets the clique of this ServerStatementSubject.  # noqa: E501

        CURIE-encoded canonical identifier of \"equivalent concepts clique\" of the subject concept   # noqa: E501

        :return: The clique of this ServerStatementSubject.  # noqa: E501
        :rtype: str
        """
        return self._clique

    @clique.setter
    def clique(self, clique):
        """Sets the clique of this ServerStatementSubject.

        CURIE-encoded canonical identifier of \"equivalent concepts clique\" of the subject concept   # noqa: E501

        :param clique: The clique of this ServerStatementSubject.  # noqa: E501
        :type: str
        """

        self._clique = clique

    @property
    def id(self):
        """Gets the id of this ServerStatementSubject.  # noqa: E501

        CURIE-encoded identifier of the subject concept   # noqa: E501

        :return: The id of this ServerStatementSubject.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerStatementSubject.

        CURIE-encoded identifier of the subject concept   # noqa: E501

        :param id: The id of this ServerStatementSubject.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ServerStatementSubject.  # noqa: E501

        human readable label of the subject concept  # noqa: E501

        :return: The name of this ServerStatementSubject.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServerStatementSubject.

        human readable label of the subject concept  # noqa: E501

        :param name: The name of this ServerStatementSubject.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def categories(self):
        """Gets the categories of this ServerStatementSubject.  # noqa: E501

        Semantic categories of the subject concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).   # noqa: E501

        :return: The categories of this ServerStatementSubject.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ServerStatementSubject.

        Semantic categories of the subject concept ((see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of categories).   # noqa: E501

        :param categories: The categories of this ServerStatementSubject.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementSubject):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerStatementPredicate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'edge_label': 'str',
        'relation': 'str',
        'negated': 'bool'
    }

    attribute_map = {
        'edge_label': 'edge_label',
        'relation': 'relation',
        'negated': 'negated'
    }

    def __init__(self, edge_label=None, relation=None, negated=None):  # noqa: E501
        """ServerStatementPredicate - a model defined in Swagger"""  # noqa: E501

        self._edge_label = None
        self._relation = None
        self._negated = None
        self.discriminator = None

        if edge_label is not None:
            self.edge_label = edge_label
        if relation is not None:
            self.relation = relation
        if negated is not None:
            self.negated = negated

    @property
    def edge_label(self):
        """Gets the edge_label of this ServerStatementPredicate.  # noqa: E501

        The predicate edge label associated with this statement, which should be as published by the /predicates API endpoint and must be taken from the minimal predicate ('slot') list of the [Biolink Model](https://biolink.github.io/biolink-model).   # noqa: E501

        :return: The edge_label of this ServerStatementPredicate.  # noqa: E501
        :rtype: str
        """
        return self._edge_label

    @edge_label.setter
    def edge_label(self, edge_label):
        """Sets the edge_label of this ServerStatementPredicate.

        The predicate edge label associated with this statement, which should be as published by the /predicates API endpoint and must be taken from the minimal predicate ('slot') list of the [Biolink Model](https://biolink.github.io/biolink-model).   # noqa: E501

        :param edge_label: The edge_label of this ServerStatementPredicate.  # noqa: E501
        :type: str
        """

        self._edge_label = edge_label

    @property
    def relation(self):
        """Gets the relation of this ServerStatementPredicate.  # noqa: E501

        The predicate relation associated with this statement, which should be as published by the /predicates API endpoint with the preferred format being a CURIE where one exists, but strings/labels acceptable. This relation may be equivalent to the edge_label (e.g. edge_label: has_phenotype, relation: RO:0002200), or a more specific relation in cases where the source provides more granularity (e.g. edge_label: molecularly_interacts_with, relation: RO:0002447)  # noqa: E501

        :return: The relation of this ServerStatementPredicate.  # noqa: E501
        :rtype: str
        """
        return self._relation

    @relation.setter
    def relation(self, relation):
        """Sets the relation of this ServerStatementPredicate.

        The predicate relation associated with this statement, which should be as published by the /predicates API endpoint with the preferred format being a CURIE where one exists, but strings/labels acceptable. This relation may be equivalent to the edge_label (e.g. edge_label: has_phenotype, relation: RO:0002200), or a more specific relation in cases where the source provides more granularity (e.g. edge_label: molecularly_interacts_with, relation: RO:0002447)  # noqa: E501

        :param relation: The relation of this ServerStatementPredicate.  # noqa: E501
        :type: str
        """

        self._relation = relation

    @property
    def negated(self):
        """Gets the negated of this ServerStatementPredicate.  # noqa: E501

        (Optional) a boolean that if set to true, indicates the edge statement is negated i.e. is not true   # noqa: E501

        :return: The negated of this ServerStatementPredicate.  # noqa: E501
        :rtype: bool
        """
        return self._negated

    @negated.setter
    def negated(self, negated):
        """Sets the negated of this ServerStatementPredicate.

        (Optional) a boolean that if set to true, indicates the edge statement is negated i.e. is not true   # noqa: E501

        :param negated: The negated of this ServerStatementPredicate.  # noqa: E501
        :type: bool
        """

        self._negated = negated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementPredicate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_predicates_by_beacon import ServerPredicatesByBeacon  # noqa: F401,E501


class ServerPredicate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'uri': 'str',
        'edge_label': 'str',
        'description': 'str',
        'beacons': 'list[ServerPredicatesByBeacon]'
    }

    attribute_map = {
        'id': 'id',
        'uri': 'uri',
        'edge_label': 'edge_label',
        'description': 'description',
        'beacons': 'beacons'
    }

    def __init__(self, id=None, uri=None, edge_label=None, description=None, beacons=None):  # noqa: E501
        """ServerPredicate - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._uri = None
        self._edge_label = None
        self._description = None
        self._beacons = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri
        if edge_label is not None:
            self.edge_label = edge_label
        if description is not None:
            self.description = description
        if beacons is not None:
            self.beacons = beacons

    @property
    def id(self):
        """Gets the id of this ServerPredicate.  # noqa: E501

        the CURIE of the predicate relation (see [Biolink Model](https://biolink.github.io/biolink-model)  # noqa: E501

        :return: The id of this ServerPredicate.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerPredicate.

        the CURIE of the predicate relation (see [Biolink Model](https://biolink.github.io/biolink-model)  # noqa: E501

        :param id: The id of this ServerPredicate.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this ServerPredicate.  # noqa: E501

        the URI of the predicate relation (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of URI)  # noqa: E501

        :return: The uri of this ServerPredicate.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ServerPredicate.

        the URI of the predicate relation (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of URI)  # noqa: E501

        :param uri: The uri of this ServerPredicate.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def edge_label(self):
        """Gets the edge_label of this ServerPredicate.  # noqa: E501

        the human readable 'edge label' of the 'minimal' predicate (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of Biolink Model minimal predicates)  # noqa: E501

        :return: The edge_label of this ServerPredicate.  # noqa: E501
        :rtype: str
        """
        return self._edge_label

    @edge_label.setter
    def edge_label(self, edge_label):
        """Sets the edge_label of this ServerPredicate.

        the human readable 'edge label' of the 'minimal' predicate (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of Biolink Model minimal predicates)  # noqa: E501

        :param edge_label: The edge_label of this ServerPredicate.  # noqa: E501
        :type: str
        """

        self._edge_label = edge_label

    @property
    def description(self):
        """Gets the description of this ServerPredicate.  # noqa: E501

        human readable definition assigned by the beacon for the predicate relation   # noqa: E501

        :return: The description of this ServerPredicate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServerPredicate.

        human readable definition assigned by the beacon for the predicate relation   # noqa: E501

        :param description: The description of this ServerPredicate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def beacons(self):
        """Gets the beacons of this ServerPredicate.  # noqa: E501

        list of metadata for beacons that support the use of this predicate relation   # noqa: E501

        :return: The beacons of this ServerPredicate.  # noqa: E501
        :rtype: list[ServerPredicatesByBeacon]
        """
        return self._beacons

    @beacons.setter
    def beacons(self, beacons):
        """Sets the beacons of this ServerPredicate.

        list of metadata for beacons that support the use of this predicate relation   # noqa: E501

        :param beacons: The beacons of this ServerPredicate.  # noqa: E501
        :type: list[ServerPredicatesByBeacon]
        """

        self._beacons = beacons

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerPredicate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_statement_annotation import ServerStatementAnnotation  # noqa: F401,E501
from kba.models.server_statement_citation import ServerStatementCitation  # noqa: F401,E501


class ServerStatementDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'keywords': 'list[str]',
        'page_number': 'int',
        'page_size': 'int',
        'is_defined_by': 'str',
        'provided_by': 'str',
        'qualifiers': 'list[str]',
        'annotation': 'list[ServerStatementAnnotation]',
        'evidence': 'list[ServerStatementCitation]'
    }

    attribute_map = {
        'id': 'id',
        'keywords': 'keywords',
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'is_defined_by': 'is_defined_by',
        'provided_by': 'provided_by',
        'qualifiers': 'qualifiers',
        'annotation': 'annotation',
        'evidence': 'evidence'
    }

    def __init__(self, id=None, keywords=None, page_number=None, page_size=None, is_defined_by=None, provided_by=None, qualifiers=None, annotation=None, evidence=None):  # noqa: E501
        """ServerStatementDetails - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._keywords = None
        self._page_number = None
        self._page_size = None
        self._is_defined_by = None
        self._provided_by = None
        self._qualifiers = None
        self._annotation = None
        self._evidence = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if keywords is not None:
            self.keywords = keywords
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if is_defined_by is not None:
            self.is_defined_by = is_defined_by
        if provided_by is not None:
            self.provided_by = provided_by
        if qualifiers is not None:
            self.qualifiers = qualifiers
        if annotation is not None:
            self.annotation = annotation
        if evidence is not None:
            self.evidence = evidence

    @property
    def id(self):
        """Gets the id of this ServerStatementDetails.  # noqa: E501

        Statement identifier of the statement made in an edge (echoed back)   # noqa: E501

        :return: The id of this ServerStatementDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerStatementDetails.

        Statement identifier of the statement made in an edge (echoed back)   # noqa: E501

        :param id: The id of this ServerStatementDetails.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def keywords(self):
        """Gets the keywords of this ServerStatementDetails.  # noqa: E501

        'keywords' string parameter to API call, echoed back   # noqa: E501

        :return: The keywords of this ServerStatementDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this ServerStatementDetails.

        'keywords' string parameter to API call, echoed back   # noqa: E501

        :param keywords: The keywords of this ServerStatementDetails.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def page_number(self):
        """Gets the page_number of this ServerStatementDetails.  # noqa: E501

        'pageNumber' string parameter to API call, echoed back   # noqa: E501

        :return: The page_number of this ServerStatementDetails.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this ServerStatementDetails.

        'pageNumber' string parameter to API call, echoed back   # noqa: E501

        :param page_number: The page_number of this ServerStatementDetails.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this ServerStatementDetails.  # noqa: E501

        'pageSize' string parameter to API call, echoed back   # noqa: E501

        :return: The page_size of this ServerStatementDetails.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ServerStatementDetails.

        'pageSize' string parameter to API call, echoed back   # noqa: E501

        :param page_size: The page_size of this ServerStatementDetails.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def is_defined_by(self):
        """Gets the is_defined_by of this ServerStatementDetails.  # noqa: E501

        A CURIE/URI for the translator group that wrapped this knowledge source ('beacon') that publishes the statement made in an edge.   # noqa: E501

        :return: The is_defined_by of this ServerStatementDetails.  # noqa: E501
        :rtype: str
        """
        return self._is_defined_by

    @is_defined_by.setter
    def is_defined_by(self, is_defined_by):
        """Sets the is_defined_by of this ServerStatementDetails.

        A CURIE/URI for the translator group that wrapped this knowledge source ('beacon') that publishes the statement made in an edge.   # noqa: E501

        :param is_defined_by: The is_defined_by of this ServerStatementDetails.  # noqa: E501
        :type: str
        """

        self._is_defined_by = is_defined_by

    @property
    def provided_by(self):
        """Gets the provided_by of this ServerStatementDetails.  # noqa: E501

        A CURIE prefix, e.g. Pharos, MGI, Monarch. The group that curated/asserted the statement made in an edge.   # noqa: E501

        :return: The provided_by of this ServerStatementDetails.  # noqa: E501
        :rtype: str
        """
        return self._provided_by

    @provided_by.setter
    def provided_by(self, provided_by):
        """Sets the provided_by of this ServerStatementDetails.

        A CURIE prefix, e.g. Pharos, MGI, Monarch. The group that curated/asserted the statement made in an edge.   # noqa: E501

        :param provided_by: The provided_by of this ServerStatementDetails.  # noqa: E501
        :type: str
        """

        self._provided_by = provided_by

    @property
    def qualifiers(self):
        """Gets the qualifiers of this ServerStatementDetails.  # noqa: E501

        (Optional) terms representing qualifiers that modify or qualify the meaning of the statement made in an edge.   # noqa: E501

        :return: The qualifiers of this ServerStatementDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._qualifiers

    @qualifiers.setter
    def qualifiers(self, qualifiers):
        """Sets the qualifiers of this ServerStatementDetails.

        (Optional) terms representing qualifiers that modify or qualify the meaning of the statement made in an edge.   # noqa: E501

        :param qualifiers: The qualifiers of this ServerStatementDetails.  # noqa: E501
        :type: list[str]
        """

        self._qualifiers = qualifiers

    @property
    def annotation(self):
        """Gets the annotation of this ServerStatementDetails.  # noqa: E501

        Extra edge properties, generally compliant with Translator Knowledge Graph Standard Specification   # noqa: E501

        :return: The annotation of this ServerStatementDetails.  # noqa: E501
        :rtype: list[ServerStatementAnnotation]
        """
        return self._annotation

    @annotation.setter
    def annotation(self, annotation):
        """Sets the annotation of this ServerStatementDetails.

        Extra edge properties, generally compliant with Translator Knowledge Graph Standard Specification   # noqa: E501

        :param annotation: The annotation of this ServerStatementDetails.  # noqa: E501
        :type: list[ServerStatementAnnotation]
        """

        self._annotation = annotation

    @property
    def evidence(self):
        """Gets the evidence of this ServerStatementDetails.  # noqa: E501


        :return: The evidence of this ServerStatementDetails.  # noqa: E501
        :rtype: list[ServerStatementCitation]
        """
        return self._evidence

    @evidence.setter
    def evidence(self, evidence):
        """Sets the evidence of this ServerStatementDetails.


        :param evidence: The evidence of this ServerStatementDetails.  # noqa: E501
        :type: list[ServerStatementCitation]
        """

        self._evidence = evidence

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerStatementDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kba.api_client import ApiClient


class ConceptsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_cliques(self, query_id, **kwargs):  # noqa: E501
        """get_cliques  # noqa: E501

        Retrieves a list of concept cliques based on  'data ready' from a previously /cliques posted query parameter submission   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_cliques(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: the query identifier of a concepts query previously posted by the /cliques endpoint (required)
        :return: ServerCliquesQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_cliques_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cliques_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_cliques_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_cliques  # noqa: E501

        Retrieves a list of concept cliques based on  'data ready' from a previously /cliques posted query parameter submission   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_cliques_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: the query identifier of a concepts query previously posted by the /cliques endpoint (required)
        :return: ServerCliquesQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cliques" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_cliques`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/cliques/data/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerCliquesQueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cliques_query_status(self, query_id, **kwargs):  # noqa: E501
        """get_cliques_query_status  # noqa: E501

        Retrieves the status of a given query about the cliques in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_cliques_query_status(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of clique query parameters. (required)
        :return: ServerCliquesQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_cliques_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_cliques_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_cliques_query_status_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_cliques_query_status  # noqa: E501

        Retrieves the status of a given query about the cliques in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_cliques_query_status_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of clique query parameters. (required)
        :return: ServerCliquesQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cliques_query_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_cliques_query_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/cliques/status/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerCliquesQueryStatus',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_concept_details(self, clique_id, **kwargs):  # noqa: E501
        """get_concept_details  # noqa: E501

        Retrieves details for a specified clique of equivalent concepts in the system,  as specified by a (url-encoded) CURIE identifier of a clique known to the aggregator   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concept_details(clique_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str clique_id: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier, as returned  by any other endpoint of the beacon aggregator API, of an exactly matching  concept clique of interest. (required)
        :param list[int] beacons: set of aggregator indices of beacons to be used as knowledge sources for the query 
        :return: ServerConceptWithDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_concept_details_with_http_info(clique_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_concept_details_with_http_info(clique_id, **kwargs)  # noqa: E501
            return data

    def get_concept_details_with_http_info(self, clique_id, **kwargs):  # noqa: E501
        """get_concept_details  # noqa: E501

        Retrieves details for a specified clique of equivalent concepts in the system,  as specified by a (url-encoded) CURIE identifier of a clique known to the aggregator   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concept_details_with_http_info(clique_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str clique_id: a [CURIE-encoded](https://www.w3.org/TR/curie/) identifier, as returned  by any other endpoint of the beacon aggregator API, of an exactly matching  concept clique of interest. (required)
        :param list[int] beacons: set of aggregator indices of beacons to be used as knowledge sources for the query 
        :return: ServerConceptWithDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['clique_id', 'beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_concept_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'clique_id' is set
        if ('clique_id' not in params or
                params['clique_id'] is None):
            raise ValueError("Missing the required parameter `clique_id` when calling `get_concept_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'clique_id' in params:
            path_params['cliqueId'] = params['clique_id']  # noqa: E501

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/concepts/details/{cliqueId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerConceptWithDetails',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_concepts(self, query_id, **kwargs):  # noqa: E501
        """get_concepts  # noqa: E501

        Retrieves a (paged) list of basic equivalent concept clique data from beacons 'data ready' from a previously /concepts posted query parameter submission   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concepts(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: the query identifier of a concepts query previously posted by the /concepts endpoint (required)
        :param list[int] beacons: set of aggregator indices of beacons whose data are to be retrieved 
        :param int page_number: (1-based) number of the page to be returned in a paged set of query results. Defaults to '1'. 
        :param int page_size: number of concepts per page to be returned in a paged set of query results. Defaults to '10'. 
        :return: ServerConceptsQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_concepts_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_concepts_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_concepts_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_concepts  # noqa: E501

        Retrieves a (paged) list of basic equivalent concept clique data from beacons 'data ready' from a previously /concepts posted query parameter submission   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concepts_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: the query identifier of a concepts query previously posted by the /concepts endpoint (required)
        :param list[int] beacons: set of aggregator indices of beacons whose data are to be retrieved 
        :param int page_number: (1-based) number of the page to be returned in a paged set of query results. Defaults to '1'. 
        :param int page_size: number of concepts per page to be returned in a paged set of query results. Defaults to '10'. 
        :return: ServerConceptsQueryResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id', 'beacons', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_concepts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_concepts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/concepts/data/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerConceptsQueryResult',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_concepts_query_status(self, query_id, **kwargs):  # noqa: E501
        """get_concepts_query_status  # noqa: E501

        Retrieves the status of a given keyword search query about the concepts in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concepts_query_status(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of concept query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose status is being polled (if omitted, then the status of all beacons from the query are returned) 
        :return: ServerConceptsQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_concepts_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_concepts_query_status_with_http_info(query_id, **kwargs)  # noqa: E501
            return data

    def get_concepts_query_status_with_http_info(self, query_id, **kwargs):  # noqa: E501
        """get_concepts_query_status  # noqa: E501

        Retrieves the status of a given keyword search query about the concepts in the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_concepts_query_status_with_http_info(query_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str query_id: an active query identifier as returned by a POST of concept query parameters. (required)
        :param list[int] beacons: subset of aggregator indices of beacons whose status is being polled (if omitted, then the status of all beacons from the query are returned) 
        :return: ServerConceptsQueryStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_id', 'beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_concepts_query_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_id' is set
        if ('query_id' not in params or
                params['query_id'] is None):
            raise ValueError("Missing the required parameter `query_id` when calling `get_concepts_query_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'query_id' in params:
            path_params['queryId'] = params['query_id']  # noqa: E501

        query_params = []
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/concepts/status/{queryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerConceptsQueryStatus',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_cliques_query(self, ids, **kwargs):  # noqa: E501
        """post_cliques_query  # noqa: E501

        Retrieves the beacon aggregator assigned cliques of equivalent concepts that includes the specified (url-encoded) CURIE identifiers. Note that the clique to which a given concept CURIE belongs may change over time as the aggregator progressively discovers the members of the clique. Any unmatched identifiers will be ignored (e.g. the id couldn't be found in any of the beacons)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_cliques_query(ids, async=True)
        >>> result = thread.get()

        :param async bool
        :param list[str] ids: an array of [CURIE-encoded](https://www.w3.org/TR/curie/) identifiers of interest to be resolved to a list of concept cliques (required)
        :return: ServerCliquesQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.post_cliques_query_with_http_info(ids, **kwargs)  # noqa: E501
        else:
            (data) = self.post_cliques_query_with_http_info(ids, **kwargs)  # noqa: E501
            return data

    def post_cliques_query_with_http_info(self, ids, **kwargs):  # noqa: E501
        """post_cliques_query  # noqa: E501

        Retrieves the beacon aggregator assigned cliques of equivalent concepts that includes the specified (url-encoded) CURIE identifiers. Note that the clique to which a given concept CURIE belongs may change over time as the aggregator progressively discovers the members of the clique. Any unmatched identifiers will be ignored (e.g. the id couldn't be found in any of the beacons)   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_cliques_query_with_http_info(ids, async=True)
        >>> result = thread.get()

        :param async bool
        :param list[str] ids: an array of [CURIE-encoded](https://www.w3.org/TR/curie/) identifiers of interest to be resolved to a list of concept cliques (required)
        :return: ServerCliquesQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_cliques_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ids' is set
        if ('ids' not in params or
                params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `post_cliques_query`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('ids', params['ids']))  # noqa: E501
            collection_formats['ids'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/cliques', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerCliquesQuery',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_concepts_query(self, keywords, **kwargs):  # noqa: E501
        """post_concepts_query  # noqa: E501

        Posts the query parameters to retrieves a list of concepts from the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_concepts_query(keywords, async=True)
        >>> result = thread.get()

        :param async bool
        :param list[str] keywords: an array of keywords or substrings against which to match concept names and synonyms (required)
        :param list[str] categories: a subset array of concept categories (specified as codes 'gene', 'pathway', etc.) to which to constrain concepts matched by the main keyword search (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of codes) 
        :param list[int] beacons: subset of aggregator indices of beacons to be used as knowledge sources for the query (if omitted, then the all beacons are queried) 
        :return: ServerConceptsQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.post_concepts_query_with_http_info(keywords, **kwargs)  # noqa: E501
        else:
            (data) = self.post_concepts_query_with_http_info(keywords, **kwargs)  # noqa: E501
            return data

    def post_concepts_query_with_http_info(self, keywords, **kwargs):  # noqa: E501
        """post_concepts_query  # noqa: E501

        Posts the query parameters to retrieves a list of concepts from the system   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_concepts_query_with_http_info(keywords, async=True)
        >>> result = thread.get()

        :param async bool
        :param list[str] keywords: an array of keywords or substrings against which to match concept names and synonyms (required)
        :param list[str] categories: a subset array of concept categories (specified as codes 'gene', 'pathway', etc.) to which to constrain concepts matched by the main keyword search (see [Biolink Model](https://biolink.github.io/biolink-model) for the full list of codes) 
        :param list[int] beacons: subset of aggregator indices of beacons to be used as knowledge sources for the query (if omitted, then the all beacons are queried) 
        :return: ServerConceptsQuery
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['keywords', 'categories', 'beacons']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_concepts_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'keywords' is set
        if ('keywords' not in params or
                params['keywords'] is None):
            raise ValueError("Missing the required parameter `keywords` when calling `post_concepts_query`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'keywords' in params:
            query_params.append(('keywords', params['keywords']))  # noqa: E501
            collection_formats['keywords'] = 'csv'  # noqa: E501
        if 'categories' in params:
            query_params.append(('categories', params['categories']))  # noqa: E501
            collection_formats['categories'] = 'csv'  # noqa: E501
        if 'beacons' in params:
            query_params.append(('beacons', params['beacons']))  # noqa: E501
            collection_formats['beacons'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/concepts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServerConceptsQuery',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kba
from kba.api.aggregator_api import AggregatorApi  # noqa: E501
from kba.rest import ApiException


class TestAggregatorApi(unittest.TestCase):
    """AggregatorApi unit test stubs"""

    def setUp(self):
        self.api = kba.api.aggregator_api.AggregatorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_beacons(self):
        """Test case for get_beacons

        """
        pass

    def test_get_concept_categories(self):
        """Test case for get_concept_categories

        """
        pass

    def test_get_error_log(self):
        """Test case for get_error_log

        """
        pass

    def test_get_knowledge_map(self):
        """Test case for get_knowledge_map

        """
        pass

    def test_get_predicates(self):
        """Test case for get_predicates

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerConceptsQueryBeaconStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'beacon': 'int',
        'status': 'int',
        'discovered': 'int',
        'processed': 'int',
        'count': 'int'
    }

    attribute_map = {
        'beacon': 'beacon',
        'status': 'status',
        'discovered': 'discovered',
        'processed': 'processed',
        'count': 'count'
    }

    def __init__(self, beacon=None, status=None, discovered=None, processed=None, count=None):  # noqa: E501
        """ServerConceptsQueryBeaconStatus - a model defined in Swagger"""  # noqa: E501

        self._beacon = None
        self._status = None
        self._discovered = None
        self._processed = None
        self._count = None
        self.discriminator = None

        if beacon is not None:
            self.beacon = beacon
        if status is not None:
            self.status = status
        if discovered is not None:
            self.discovered = discovered
        if processed is not None:
            self.processed = processed
        if count is not None:
            self.count = count

    @property
    def beacon(self):
        """Gets the beacon of this ServerConceptsQueryBeaconStatus.  # noqa: E501

        Index number of beacon providing these concept details   # noqa: E501

        :return: The beacon of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :rtype: int
        """
        return self._beacon

    @beacon.setter
    def beacon(self, beacon):
        """Sets the beacon of this ServerConceptsQueryBeaconStatus.

        Index number of beacon providing these concept details   # noqa: E501

        :param beacon: The beacon of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :type: int
        """

        self._beacon = beacon

    @property
    def status(self):
        """Gets the status of this ServerConceptsQueryBeaconStatus.  # noqa: E501

        Http code status of beacon API - 200 means 'data ready', 102 means 'query in progress', other codes (e.g. 500) are server errors. Once a beacon has a '200' success code, then the /concepts/data  endpoint may be used to retrieve it.   # noqa: E501

        :return: The status of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ServerConceptsQueryBeaconStatus.

        Http code status of beacon API - 200 means 'data ready', 102 means 'query in progress', other codes (e.g. 500) are server errors. Once a beacon has a '200' success code, then the /concepts/data  endpoint may be used to retrieve it.   # noqa: E501

        :param status: The status of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def discovered(self):
        """Gets the discovered of this ServerConceptsQueryBeaconStatus.  # noqa: E501

        A count of how many items a beacon has returned. This number will not always be the same as the final number of results since we merge duplicate items.   # noqa: E501

        :return: The discovered of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :rtype: int
        """
        return self._discovered

    @discovered.setter
    def discovered(self, discovered):
        """Sets the discovered of this ServerConceptsQueryBeaconStatus.

        A count of how many items a beacon has returned. This number will not always be the same as the final number of results since we merge duplicate items.   # noqa: E501

        :param discovered: The discovered of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :type: int
        """

        self._discovered = discovered

    @property
    def processed(self):
        """Gets the processed of this ServerConceptsQueryBeaconStatus.  # noqa: E501

        A count of how many of the beacon responses have been processed and are ready for consumption.   # noqa: E501

        :return: The processed of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :rtype: int
        """
        return self._processed

    @processed.setter
    def processed(self, processed):
        """Sets the processed of this ServerConceptsQueryBeaconStatus.

        A count of how many of the beacon responses have been processed and are ready for consumption.   # noqa: E501

        :param processed: The processed of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :type: int
        """

        self._processed = processed

    @property
    def count(self):
        """Gets the count of this ServerConceptsQueryBeaconStatus.  # noqa: E501

        When a 200 status code is returned, this integer designates  the number of concepts matched by the query for the given beacon.   # noqa: E501

        :return: The count of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ServerConceptsQueryBeaconStatus.

        When a 200 status code is returned, this integer designates  the number of concepts matched by the query for the given beacon.   # noqa: E501

        :param count: The count of this ServerConceptsQueryBeaconStatus.  # noqa: E501
        :type: int
        """

        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConceptsQueryBeaconStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ServerBeaconConceptCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'uri': 'str',
        'category': 'str',
        'frequency': 'int'
    }

    attribute_map = {
        'id': 'id',
        'uri': 'uri',
        'category': 'category',
        'frequency': 'frequency'
    }

    def __init__(self, id=None, uri=None, category=None, frequency=None):  # noqa: E501
        """ServerBeaconConceptCategory - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._uri = None
        self._category = None
        self._frequency = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri
        if category is not None:
            self.category = category
        if frequency is not None:
            self.frequency = frequency

    @property
    def id(self):
        """Gets the id of this ServerBeaconConceptCategory.  # noqa: E501

        the 'local' CURIE-encoded identifier of the given concept category, as published by the given beacon   # noqa: E501

        :return: The id of this ServerBeaconConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerBeaconConceptCategory.

        the 'local' CURIE-encoded identifier of the given concept category, as published by the given beacon   # noqa: E501

        :param id: The id of this ServerBeaconConceptCategory.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this ServerBeaconConceptCategory.  # noqa: E501

        the 'local' URI of the given concept category, as published by the given beacon   # noqa: E501

        :return: The uri of this ServerBeaconConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ServerBeaconConceptCategory.

        the 'local' URI of the given concept category, as published by the given beacon   # noqa: E501

        :param uri: The uri of this ServerBeaconConceptCategory.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def category(self):
        """Gets the category of this ServerBeaconConceptCategory.  # noqa: E501

        the 'local' human readable label of the given concept category, as published by the given beacon   # noqa: E501

        :return: The category of this ServerBeaconConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ServerBeaconConceptCategory.

        the 'local' human readable label of the given concept category, as published by the given beacon   # noqa: E501

        :param category: The category of this ServerBeaconConceptCategory.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def frequency(self):
        """Gets the frequency of this ServerBeaconConceptCategory.  # noqa: E501

        the number of instances of the specified concept category is used in statements within the given beacon   # noqa: E501

        :return: The frequency of this ServerBeaconConceptCategory.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ServerBeaconConceptCategory.

        the number of instances of the specified concept category is used in statements within the given beacon   # noqa: E501

        :param frequency: The frequency of this ServerBeaconConceptCategory.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerBeaconConceptCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from kba.api.concepts_api import ConceptsApi
from kba.api.metadata_api import MetadataApi
from kba.api.statements_api import StatementsApi

# import ApiClient
from kba.api_client import ApiClient
from kba.configuration import Configuration
# import models into sdk package
from kba.models.server_beacon_concept_category import ServerBeaconConceptCategory
from kba.models.server_beacon_predicate import ServerBeaconPredicate
from kba.models.server_clique import ServerClique
from kba.models.server_cliques_query import ServerCliquesQuery
from kba.models.server_cliques_query_beacon_status import ServerCliquesQueryBeaconStatus
from kba.models.server_cliques_query_result import ServerCliquesQueryResult
from kba.models.server_cliques_query_status import ServerCliquesQueryStatus
from kba.models.server_concept import ServerConcept
from kba.models.server_concept_categories_by_beacon import ServerConceptCategoriesByBeacon
from kba.models.server_concept_category import ServerConceptCategory
from kba.models.server_concept_detail import ServerConceptDetail
from kba.models.server_concept_with_details import ServerConceptWithDetails
from kba.models.server_concept_with_details_beacon_entry import ServerConceptWithDetailsBeaconEntry
from kba.models.server_concepts_query import ServerConceptsQuery
from kba.models.server_concepts_query_beacon_status import ServerConceptsQueryBeaconStatus
from kba.models.server_concepts_query_result import ServerConceptsQueryResult
from kba.models.server_concepts_query_status import ServerConceptsQueryStatus
from kba.models.server_knowledge_beacon import ServerKnowledgeBeacon
from kba.models.server_knowledge_map import ServerKnowledgeMap
from kba.models.server_knowledge_map_object import ServerKnowledgeMapObject
from kba.models.server_knowledge_map_predicate import ServerKnowledgeMapPredicate
from kba.models.server_knowledge_map_statement import ServerKnowledgeMapStatement
from kba.models.server_knowledge_map_subject import ServerKnowledgeMapSubject
from kba.models.server_log_entry import ServerLogEntry
from kba.models.server_predicate import ServerPredicate
from kba.models.server_predicates_by_beacon import ServerPredicatesByBeacon
from kba.models.server_statement import ServerStatement
from kba.models.server_statement_annotation import ServerStatementAnnotation
from kba.models.server_statement_citation import ServerStatementCitation
from kba.models.server_statement_details import ServerStatementDetails
from kba.models.server_statement_object import ServerStatementObject
from kba.models.server_statement_predicate import ServerStatementPredicate
from kba.models.server_statement_subject import ServerStatementSubject
from kba.models.server_statements_query import ServerStatementsQuery
from kba.models.server_statements_query_beacon_status import ServerStatementsQueryBeaconStatus
from kba.models.server_statements_query_result import ServerStatementsQueryResult
from kba.models.server_statements_query_status import ServerStatementsQueryStatus



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kba.api.concepts_api import ConceptsApi
from kba.api.metadata_api import MetadataApi
from kba.api.statements_api import StatementsApi



# coding: utf-8

"""
    Translator Knowledge Beacon Aggregator API

    This is the Translator Knowledge Beacon Aggregator web service application programming interface (API) that provides integrated access to a pool of knowledge sources publishing concepts and relations through the Translator Knowledge Beacon API. This API is similar to that of the latter mentioned API with the addition of some extra informative endpoints plus session identifier and beacon indices. These latter identifiers are locally assigned numeric indices provided to track the use of specific registered beacons within the aggregator API itself.   # noqa: E501

    OpenAPI spec version: 1.1.3
    Contact: richard@starinformatics.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kba.models.server_concept_categories_by_beacon import ServerConceptCategoriesByBeacon  # noqa: F401,E501


class ServerConceptCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'uri': 'str',
        'category': 'str',
        'description': 'str',
        'beacons': 'list[ServerConceptCategoriesByBeacon]'
    }

    attribute_map = {
        'id': 'id',
        'uri': 'uri',
        'category': 'category',
        'description': 'description',
        'beacons': 'beacons'
    }

    def __init__(self, id=None, uri=None, category=None, description=None, beacons=None):  # noqa: E501
        """ServerConceptCategory - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._uri = None
        self._category = None
        self._description = None
        self._beacons = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri
        if category is not None:
            self.category = category
        if description is not None:
            self.description = description
        if beacons is not None:
            self.beacons = beacons

    @property
    def id(self):
        """Gets the id of this ServerConceptCategory.  # noqa: E501

        the CURIE of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model)  # noqa: E501

        :return: The id of this ServerConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServerConceptCategory.

        the CURIE of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model)  # noqa: E501

        :param id: The id of this ServerConceptCategory.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this ServerConceptCategory.  # noqa: E501

        the URI of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model)  for the full list of URI)  # noqa: E501

        :return: The uri of this ServerConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ServerConceptCategory.

        the URI of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model)  for the full list of URI)  # noqa: E501

        :param uri: The uri of this ServerConceptCategory.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def category(self):
        """Gets the category of this ServerConceptCategory.  # noqa: E501

        the human readable label of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model) for  the full list of concept categories)   # noqa: E501

        :return: The category of this ServerConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ServerConceptCategory.

        the human readable label of the concept category (see [Biolink Model Classes](https://biolink.github.io/biolink-model) for  the full list of concept categories)   # noqa: E501

        :param category: The category of this ServerConceptCategory.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def description(self):
        """Gets the description of this ServerConceptCategory.  # noqa: E501

        human readable definition assigned by the beacon for the specified concept category   # noqa: E501

        :return: The description of this ServerConceptCategory.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServerConceptCategory.

        human readable definition assigned by the beacon for the specified concept category   # noqa: E501

        :param description: The description of this ServerConceptCategory.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def beacons(self):
        """Gets the beacons of this ServerConceptCategory.  # noqa: E501

        list of metadata for beacons that support the use of this concept category   # noqa: E501

        :return: The beacons of this ServerConceptCategory.  # noqa: E501
        :rtype: list[ServerConceptCategoriesByBeacon]
        """
        return self._beacons

    @beacons.setter
    def beacons(self, beacons):
        """Sets the beacons of this ServerConceptCategory.

        list of metadata for beacons that support the use of this concept category   # noqa: E501

        :param beacons: The beacons of this ServerConceptCategory.  # noqa: E501
        :type: list[ServerConceptCategoriesByBeacon]
        """

        self._beacons = beacons

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerConceptCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
